@@ -86,7 +86,7 @@ class PureThriftFormatter(object):
             ThriftParser.Enum_ruleContext,
             ThriftParser.Struct_Context,
             ThriftParser.Union_Context,
-            ThriftParser.ExceptionContext,
+            ThriftParser.Exception_Context,
             ThriftParser.ServiceContext,
         ))
 
@@ -127,16 +127,9 @@ class PureThriftFormatter(object):
                         self._push(join)
                 self.process_node(child)
         return fn
-    _gen_inline_Context = gen_inline_Context.__func__
-
-    def before_subfields_hook(self, _: List[ParseTree]):
-        pass
-
-    def after_subfields_hook(self, _: List[ParseTree]):
-        pass
 
     @staticmethod
-    def _gen_subfields_Context(start: int, field_class: typing.Type):
+    def gen_subfields_Context(start: int, field_class: typing.Type):
         def fn(self: PureThriftFormatter, node: ParseTree):
             self._inline_nodes(node.children[:start])
             self._newline()
@@ -150,6 +143,15 @@ class PureThriftFormatter(object):
             self._inline_nodes(left)
         return fn
 
+    _gen_inline_Context = gen_inline_Context.__func__
+    _gen_subfields_Context = gen_subfields_Context.__func__
+
+    def before_subfields_hook(self, _: List[ParseTree]):
+        pass
+
+    def after_subfields_hook(self, _: List[ParseTree]):
+        pass
+
     def process_node(self, node: ParseTree):
         if not isinstance(node, TerminalNodeImpl):
             for child in node.children:
@@ -206,7 +208,7 @@ class PureThriftFormatter(object):
     Enum_ruleContext = _gen_subfields_Context(3, ThriftParser.Enum_fieldContext)
     Struct_Context = _gen_subfields_Context(3, ThriftParser.FieldContext)
     Union_Context = _gen_subfields_Context(3, ThriftParser.FieldContext)
-    ExceptionContext = _gen_subfields_Context(3, ThriftParser.FieldContext)
+    Exception_Context = _gen_subfields_Context(3, ThriftParser.FieldContext)
     Enum_fieldContext = _gen_inline_Context(
         join=' ',
         tight_fn=lambda _, n: isinstance(n, ThriftParser.List_separatorContext))
@@ -234,9 +236,9 @@ class PureThriftFormatter(object):
     Annotation_valueContext = _gen_inline_Context()
 
     def ServiceContext(self, node: ThriftParser.ServiceContext):
-        fn = self._gen_subfields_Context(3, ThriftParser.Function_Context)
+        fn = self.gen_subfields_Context(3, ThriftParser.Function_Context)
         if self._is_token(node.children[2], 'extends'):
-            fn = self._gen_subfields_Context(5, ThriftParser.Function_Context)
+            fn = self.gen_subfields_Context(5, ThriftParser.Function_Context)
         return fn(self, node)
 
     def SenumContext(self, node: ThriftParser.SenumContext):
